==> openshift-model-config-6.8.1-sources.jar: io/fabric8/openshift/api/model/config/v1/ExternalPlatformSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExternalPlatformSpecFluent<A extends ExternalPlatformSpecFluent<A>> extends BaseFluent<A>{
  public ExternalPlatformSpecFluent() {
  }
  public ExternalPlatformSpecFluent(ExternalPlatformSpec instance) {
    instance = (instance != null ? instance : new ExternalPlatformSpec());

    if (instance != null) {
      this.withPlatformName(instance.getPlatformName());
      this.withPlatformName(instance.getPlatformName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String platformName;
  private Map<String,Object> additionalProperties;
  public String getPlatformName() {
    return this.platformName;
  }
  public A withPlatformName(String platformName) {
    this.platformName=platformName; return (A) this;
  }
  public boolean hasPlatformName() {
    return this.platformName != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalPlatformSpecFluent that = (ExternalPlatformSpecFluent) o;
    if (!java.util.Objects.equals(platformName, that.platformName)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(platformName,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (platformName != null) { sb.append("platformName:"); sb.append(platformName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ExternalPlatformSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ExternalPlatformSpecFluent<A extends ExternalPlatformSpecFluent<A>> extends BaseFluent<A>{
  public ExternalPlatformSpecFluent() {
  }
  
  public ExternalPlatformSpecFluent(ExternalPlatformSpec instance) {
    this.copyInstance(instance);
  }
  private String platformName;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ExternalPlatformSpec instance) {
    instance = (instance != null ? instance : new ExternalPlatformSpec());
  
    if (instance != null) {
        this.withPlatformName(instance.getPlatformName());
        this.withPlatformName(instance.getPlatformName());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getPlatformName() {
    return this.platformName;
  }
  
  public A withPlatformName(String platformName) {
    this.platformName=platformName; return (A) this;
  }
  
  public boolean hasPlatformName() {
    return this.platformName != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalPlatformSpecFluent that = (ExternalPlatformSpecFluent) o;
    if (!java.util.Objects.equals(platformName, that.platformName)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(platformName,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (platformName != null) { sb.append("platformName:"); sb.append(platformName + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
